package ballerina.lang.strings;

@doc:Description ("Returns a new string that is the substring of the specified string")
@doc:Param ("mainString: The original string argument" )
@doc:Param ("from: The starting index" )
@doc:Param ("to: The ending index" )
@doc:Return ("string: The derived sub string" )
native function subString (string mainString, int from, int to) (string);

@doc:Description ("Returns the length of the specified string ")
@doc:Param ("s: The original string argument" )
@doc:Return ("int: The length of the specified string" )
native function length (string s) (int);

@doc:Description ("Returns a string representation of a Boolean argument")
@doc:Param ("b: A Boolean argument" )
@doc:Return ("string: String representation of the specified Boolean argument" )
native function valueOf (boolean b) (string);

@doc:Description ("Returns a Boolean value indicating whether a string contains the specified substring")
@doc:Param ("mainString: The original string argument" )
@doc:Param ("subString: The substring to be compared" )
@doc:Return ("boolean: True if the string contains the substring; false otherwise" )
native function contains (string mainString, string subString) (boolean);

@doc:Description ("Returns the first index of the last occurence of the substring within the specified string")
@doc:Param ("mainString: The original string argument" )
@doc:Param ("subString: The substring to search for" )
@doc:Return ("int: The index of the last occurence of the substring" )
native function lastIndexOf (string mainString, string subString) (int);

@doc:Description ("Replaces the first instance of the replacePattern with the replaceWith string and returns the result")
@doc:Param ("mainString: The original string argument" )
@doc:Param ("replacePattern: The pattern to search for " )
@doc:Param ("replaceWith: The replacement string" )
@doc:Return ("string: The derived string" )
native function replaceFirst (string mainString, string replacePattern, string replaceWith) (string);

@doc:Description ("Returns a Boolean value indicating whether the string ends with specified suffix")
@doc:Param ("mainString: The original string argument" )
@doc:Param ("suffix: The suffix to be compared" )
@doc:Return ("boolean: True if the string ends with the suffix; false otherwise" )
native function hasSuffix (string mainString, string suffix) (boolean);

@doc:Description ("Replaces the replacePattern string with the replaceWith string and returns the result")
@doc:Param ("mainString: The original string argument" )
@doc:Param ("replacePattern: The pattern to search for " )
@doc:Param ("replaceWith: The replacement string" )
@doc:Return ("string: The derived string" )
native function replace (string mainString, string replacePattern, string replaceWith) (string);

@doc:Description ("Returns an unescaped string by omitting the escape characters of the original string")
@doc:Param ("s: The original string argument" )
@doc:Return ("string: The derived string" )
native function unescape (string s) (string);

@doc:Description ("Returns a string representation of a long argument")
@doc:Param ("l: A long argument" )
@doc:Return ("string: String representation of the specified long argument" )
native function valueOf (long l) (string);

@doc:Description ("Returns a Boolean value indicating whether a string starts with the specified prefix")
@doc:Param ("mainString: The original string argument" )
@doc:Param ("prefix: The prefix to be compared" )
@doc:Return ("boolean: True if the string starts with the prefix; false otherwise" )
native function hasPrefix (string mainString, string prefix) (boolean);

@doc:Description ("Returns the string representation of a string argument")
@doc:Param ("s: The specified string argument" )
@doc:Return ("string: String representation of the specified string argument" )
native function valueOf (string s) (string);

@doc:Description ("Returns a string representation of a JSON argument")
@doc:Param ("value: A JSON argument" )
@doc:Return ("string: String representation of the specified JSON argument" )
native function valueOf (json value) (string);

@doc:Description ("Compares two strings, ignoring the case of the strings")
@doc:Param ("mainString: The original string argument" )
@doc:Param ("anotherString: The string to be compared" )
@doc:Return ("boolean: True if the strings are equal; false otherwise" )
native function equalsIgnoreCase (string mainString, string anotherString) (boolean);

@doc:Description ("Returns a string representation of a float argument")
@doc:Param ("f: A float argument" )
@doc:Return ("string: String representation of the specified float argument" )
native function valueOf (float f) (string);

@doc:Description ("Returns the first index of the first occurence of the substring within the specified string")
@doc:Param ("mainString: The original string argument" )
@doc:Param ("subString: The substring to search for" )
@doc:Return ("int: The index of the first occurence of the substring" )
native function indexOf (string mainString, string subString) (int);

@doc:Description ("Replaces all instances of the replacePattern with the replaceWith string and returns the result")
@doc:Param ("mainString: The original string argument" )
@doc:Param ("replacePattern: The pattern to search for " )
@doc:Param ("replaceWith: The replacement string" )
@doc:Return ("string: The derived string" )
native function replaceAll (string mainString, string replacePattern, string replaceWith) (string);

@doc:Description ("Returns a string with all the characters converted to lowercase")
@doc:Param ("s: The original string argument" )
@doc:Return ("string: The string converted to lowercase" )
native function toLowerCase (string s) (string);

@doc:Description ("Returns a trimmed string by omitting the leading and trailing whitespaces of the original string")
@doc:Param ("s: The original string argument" )
@doc:Return ("string: The derived string" )
native function trim (string s) (string);

@doc:Description ("Returns a string representation of an integer argument")
@doc:Param ("i: An integer argument" )
@doc:Return ("string: String representation of the specified integer argument" )
native function valueOf (int i) (string);

@doc:Description ("Returns a string representation of a double argument")
@doc:Param ("d: A double argument" )
@doc:Return ("string: String representation of the specified double argument" )
native function valueOf (double d) (string);

@doc:Description ("Returns a string representation of an XML argument")
@doc:Param ("e: The XML object argument" )
@doc:Return ("string: String representation of the specified XML object" )
native function valueOf (xml e) (string);

@doc:Description ("Returns a string with all the characters converted to uppercase")
@doc:Param ("s: The original string argument" )
@doc:Return ("string: The string converted to uppercase" )
native function toUpperCase (string s) (string);

